@@ -74,6 +74,11 @@ class Receiver:
             self.SHARED_LOGIC_YARN_V: str = env["PARASUT_SHARED_LOGIC_YARN_V"]
             self.SHARED_LOGIC_EMBER_PORT: str = env["PARASUT_SHARED_LOGIC_EMBER_PORT"]
             self.SHARED_LOGIC_DIR: str = env["PARASUT_SHARED_LOGIC_DIR"]
+            # printx
+            self.PRINTX_NODE_V: str = env["PARASUT_PRINTX_NODE_V"]
+            self.PRINTX_YARN_V: str = env["PARASUT_PRINTX_YARN_V"]
+            self.PRINTX_EMBER_PORT: str = env["PARASUT_PRINTX_EMBER_PORT"]
+            self.PRINTX_DIR: str = env["PARASUT_PRINTX_DIR"]
         except KeyError as e:
             print(f"Please set environment variable: {e}")
             sys.exit(0)
@@ -185,6 +190,12 @@ class Receiver:
             choose_node_version=f"asdf local nodejs {self.SHARED_LOGIC_NODE_V}",
             ember_serve=f"ember s --live-reload-port {self.SHARED_LOGIC_EMBER_PORT}",
         )
+        self._printx_commands: Dict[str, str] = dict(
+            launch_text_editor=self.PARASUT_CLI_TEXT_EDITOR,
+            choose_yarn_version=f"asdf local yarn {self.PRINTX_YARN_V}",
+            choose_node_version=f"asdf local nodejs {self.PRINTX_NODE_V}",
+            ember_serve=f"./node_modules/ember-cli/bin/ember s --live-reload-port {self.PRINTX_EMBER_PORT}",
+        )
         # run tasks
         self._task_run_server = " && ".join(
             [
@@ -279,7 +290,6 @@ class Receiver:
                 self._npm_release_commands["npm_publish"],
                 self._npm_release_commands["npm_delete_registry"],
                 self._core_commands["git_push_origin_master"],
-                self._core_commands["git_push_tags"],
             ]
         )
         self._task_auto_release_shared_logic = " && ".join(
@@ -296,7 +306,6 @@ class Receiver:
                 self._npm_auto_release_commands["npm_publish"],
                 self._npm_auto_release_commands["npm_delete_registry"],
                 self._core_commands["git_push_origin_master"],
-                self._core_commands["git_push_tags"],
             ]
         )
         self._task_run_trinity = " && ".join(
@@ -329,7 +338,6 @@ class Receiver:
                 self._npm_release_commands["npm_publish"],
                 self._npm_release_commands["npm_delete_registry"],
                 self._core_commands["git_push_origin_develop"],
-                self._core_commands["git_push_tags"],
             ]
         )
         self._task_auto_release_ui_library = " && ".join(
@@ -346,7 +354,6 @@ class Receiver:
                 self._npm_auto_release_commands["npm_publish"],
                 self._npm_auto_release_commands["npm_delete_registry"],
                 self._core_commands["git_push_origin_develop"],
-                self._core_commands["git_push_tags"],
             ]
         )
         self._task_run_client = " && ".join(
@@ -357,6 +364,14 @@ class Receiver:
                 self._client_commands["ember_serve"],
             ]
         )
+        self._task_run_printx = " && ".join(
+            [
+                self._core_commands["source_asdf"],
+                self._printx_commands["choose_yarn_version"],
+                self._printx_commands["choose_node_version"],
+                self._printx_commands["ember_serve"],
+            ]
+        )
         # switch tasks
         self._task_switch_frontend_to_phoenix = " && ".join(
             [
@@ -442,6 +457,8 @@ class Receiver:
                 self._run_process([self._task_run_ui_library], show_output=True)
             elif repo_name == "client":
                 self._run_process([self._task_run_client], show_output=True)
+            elif repo_name == "printx":
+                self._run_process([self._task_run_client], show_output=True)
         except KeyboardInterrupt:
             pass
         except Exception as e:
@@ -547,6 +564,11 @@ class Receiver:
                     f"{self.PARASUT_BASE_DIR}/{self.SHARED_LOGIC_DIR}"
                 )
                 self._launch_parasut_shared_logic_repo()
+            elif repo_name == "printx":
+                self._change_directory(
+                    f"{self.PARASUT_BASE_DIR}/{self.PRINTX_DIR}"
+                )
+                self._launch_parasut_printx_repo()
 
         # kill the first empty window if new session initialized
         if not session:
@@ -610,6 +632,11 @@ class Receiver:
                     f"{self.PARASUT_BASE_DIR}/{self.SHARED_LOGIC_DIR}"
                 )
                 self._launch_parasut_shared_logic_editor()
+            elif repo_name == "printx":
+                self._change_directory(
+                    f"{self.PARASUT_BASE_DIR}/{self.PRINTX_DIR}"
+                )
+                self._launch_parasut_printx_editor()
 
         # kill the first empty window if new session initialized
         if not session:
@@ -971,6 +998,8 @@ class Receiver:
             return f"{self.PARASUT_BASE_DIR}/{self.TRINITY_DIR}"
         elif repo_name == "ui-library":
             return f"{self.PARASUT_BASE_DIR}/{self.UI_LIBRARY_DIR}"
+        elif repo_name == "printx":
+            return f"{self.PARASUT_BASE_DIR}/{self.PRINTX_DIR}"
         else:
             raise Exception(
                 "Exiting because of an error: wrong repo path. couldn't find the repo"
@@ -1405,3 +1434,35 @@ class Receiver:
                 ]
             )
         )
+
+    def _launch_parasut_printx_repo(self) -> None:
+        printx_window: Window = self._tmux_session_parasut_ws_setup.new_window(
+            attach=False, window_name="printx"
+        )
+        printx_pane: Pane = printx_window.attached_pane
+
+        printx_pane.send_keys(
+            " && ".join(
+                [
+                    self._printx_commands["choose_yarn_version"],
+                    self._printx_commands["choose_node_version"],
+                    self._printx_commands["ember_serve"],
+                ]
+            )
+        )
+
+    def _launch_parasut_printx_editor(self) -> None:
+        printx_window: Window = self._tmux_session_parasut_ws_editor.new_window(
+            attach=False, window_name="printx"
+        )
+        printx_pane: Pane = printx_window.attached_pane
+
+        printx_pane.send_keys(
+            " && ".join(
+                [
+                    self._printx_commands["choose_yarn_version"],
+                    self._printx_commands["choose_node_version"],
+                    self._printx_commands["launch_text_editor"],
+                ]
+            )
+        )
